searchData={"items":[{"type":"task","title":"mix recode","doc":"Runs the linter.\n\n```shell\n> mix recode [options] [inputs]\n```\n\nWithout a `inputs` argument the `inputs` value from the config is used. The\n`inputs` argument accepts a wildcard.\n\nIf `inputs` value is `-`, then the input is read from stdin.\n\nWithout the option `--config file` the config file `.recode.exs` is used. A\ndefault `.recode.exs` can be generated with `mix recode.gen.config`.","ref":"Mix.Tasks.Recode.html"},{"type":"task","title":"Command line Option - mix recode","doc":"* `--autocorrect`, `--no-autocorrect` - Activates/deactivates autocrrection.\n    Overwrites the corresponding value in the configuration.\n\n  * `--config` - specifies an alternative config file.\n\n  * `--dry`, `--no-dry` - Activates/deactivates the dry mode. No file is\n    overwritten in dry mode. Overwrites the corresponding value in the\n    configuration.\n\n  * `--verbose`, `--no-verbose` - Activate/deactivates the verbose mode.\n    Overwrites the corresponding value in the configuration.\n\n  * `--task`, specifies the task to use. With this option, the task is used\n    even if it is specified as `active:  false` in the configuration.","ref":"Mix.Tasks.Recode.html#module-command-line-option"},{"type":"task","title":"mix recode.gen.config","doc":"Generates a new config for Recode. Writes the file `.recode.exs` in the root directory of the mix\nproject.\n\nThe default config:\n```elixir\nalias Recode.Task\n\n[\n  version: \"0.5.1\",\n  # Can also be set/reset with \"--autocorrect\"/\"--no-autocorrect\".\n  autocorrect: true,\n  # With \"--dry\" no changes will be written to the files.\n  # Can also be set/reset with \"--dry\"/\"--no-dry\".\n  # If dry is true then verbose is also active.\n  dry: false,\n  # Can also be set/reset with \"--verbose\"/\"--no-verbose\".\n  verbose: false,\n  # Can be overwriten by calling `mix recode \"lib/**/*.ex\"`.\n  inputs: [\"{apps,config,lib,test}/**/*.{ex,exs}\"],\n  formatter: {Recode.Formatter, []},\n  tasks: [\n    # Tasks could be added by a tuple of the tasks module name and an options\n    # keyword list. A task can be deactived by `active: false`. The execution of\n    # a deactivated task can be forced by calling `mix recode --task ModuleName`.\n    {Task.AliasExpansion, []},\n    {Task.AliasOrder, []},\n    {Task.EnforceLineLength, active: false},\n    {Task.PipeFunOne, []},\n    {Task.SinglePipe, []},\n    {Task.Specs, exclude: \"test/**/*.{ex,exs}\", config: [only: :visible]},\n    {Task.TestFileExt, []},\n    {Task.UnusedVariable, active: false}\n  ]\n]\n\n```","ref":"Mix.Tasks.Recode.Gen.Config.html"},{"type":"module","title":"Recode","doc":"A linter with autocorrection and a refactoring tool.","ref":"Recode.html"},{"type":"module","title":"Recode.AST","doc":"This module provides functions to get informations from the AST and to\nmanipulate the AST.\n\nMost of the functions in this module require an AST with additional\ninformations. This information is provided by `Sourceror` or\n`Code.string_to_quoted/2` with the options\n```elixir\n[\n  columns: true,\n  literal_encoder: &{:ok, {:__block__, &2, [&1]}},\n  token_metadata: true,\n  unescape: false\n]\n```\nSee also [Formatting considerations](https://hexdocs.pm/elixir/Code.html#quoted_to_algebra/2-formatting-considerations)\nin the docs for `Code.quoted_to_algebra/2`.\n\nThis module provides `literal?` functions that are also work with encoded\nliterals generate by `literal_encoder: %{:ok, {:__block__, &2, [&1]}}`.\nFor an example see `atom?/1`.","ref":"Recode.AST.html"},{"type":"function","title":"Recode.AST.alias_info/1","doc":"Returns the infos from an AST representing an `alias` expression.\n\nThe function returns 3-tuple containing the alias, the multi part and the\n`:as`.","ref":"Recode.AST.html#alias_info/1"},{"type":"function","title":"Examples - Recode.AST.alias_info/1","doc":"iex> ast = quote do\n    ...>   alias Foo.Bar\n    ...> end\n    iex> alias_info(ast)\n    {Foo.Bar, [], nil}\n\n    iex> ast = quote do\n    ...>   alias Foo.{Bar, Baz}\n    ...> end\n    iex> alias_info(ast)\n    {Foo, [Bar, Baz], nil}\n\n    iex> ast = quote do\n    ...>   alias Foo, as: Baz\n    ...> end\n    iex> alias_info(ast)\n    {Foo, [], Baz}","ref":"Recode.AST.html#alias_info/1-examples"},{"type":"function","title":"Recode.AST.aliases_concat/1","doc":"Concatinates the aliases of an `:__aliases__` tuple.","ref":"Recode.AST.html#aliases_concat/1"},{"type":"function","title":"Examples - Recode.AST.aliases_concat/1","doc":"iex> aliases_concat({:__aliases__, [], [:Alpha, :Bravo]})\n    Alpha.Bravo","ref":"Recode.AST.html#aliases_concat/1-examples"},{"type":"function","title":"Recode.AST.atom?/1","doc":"Returns `true` if the given AST represents an atom.","ref":"Recode.AST.html#atom?/1"},{"type":"function","title":"Examples - Recode.AST.atom?/1","doc":"iex> \":atom\" |> Code.string_to_quoted!() |> atom?()\n    true\n\n    iex> \":atom\" |> Sourceror.parse_string!() |> atom?()\n    true\n\n    iex> \"42\" |> Sourceror.parse_string!() |> atom?()\n    false\n\n    iex> ast = Code.string_to_quoted!(\n    ...>   \":a\", literal_encoder: &{:ok, {:__block__, &2, [&1]}})\n    {:__block__, [line: 1], [:a]}\n    iex> atom?(ast)\n    true","ref":"Recode.AST.html#atom?/1-examples"},{"type":"function","title":"Recode.AST.first_line/1","doc":"Returns the line in which the given AST starts.\n\nNote: The AST must be constructed by `Sourceror` or with the `Code` module and\nthe options `columns: true, token_metadata: true`.","ref":"Recode.AST.html#first_line/1"},{"type":"function","title":"Examples - Recode.AST.first_line/1","doc":"iex> code = \"\"\"\n    ...> 1 +\n    ...>   2 -\n    ...>   3\n    ...> \"\"\"\n    iex> code |> Sourceror.parse_string!() |> first_line()\n    1\n    iex> code |> Sourceror.parse_string!() |> last_line()\n    3\n    iex> code\n    ...> |> Code.string_to_quoted!(\n    ...>   columns: true,\n    ...>   token_metadata: true,\n    ...>   literal_encoder: &{:ok, {:__block__, &2, [&1]}})\n    ...> |> last_line()\n    3","ref":"Recode.AST.html#first_line/1-examples"},{"type":"function","title":"Recode.AST.get_newlines/1","doc":"Returns the `newlines` value from `meta[:end_of_expression]`, or `nil`.","ref":"Recode.AST.html#get_newlines/1"},{"type":"function","title":"Recode.AST.get_value/1","doc":"Returns the value from a `:__block__` with a single argument.","ref":"Recode.AST.html#get_value/1"},{"type":"function","title":"Examples - Recode.AST.get_value/1","doc":"iex> \"[1, 2]\"\n    ...> |> Sourceror.parse_string!()\n    ...> |> get_value()\n    ...> |> Enum.map(&get_value/1)\n    [1, 2]","ref":"Recode.AST.html#get_value/1-examples"},{"type":"function","title":"Recode.AST.last_line/1","doc":"","ref":"Recode.AST.html#last_line/1"},{"type":"function","title":"Recode.AST.mfa/1","doc":"Returns a `mfa`-tuple for the given `.`-call.","ref":"Recode.AST.html#mfa/1"},{"type":"function","title":"Recode.AST.multiline?/1","doc":"Returns `true` when the given `ast` represents an expression that spans over\nmultiple lines.\n\n`multiline?` does not pay attention to do blocks.","ref":"Recode.AST.html#multiline?/1"},{"type":"function","title":"Examples - Recode.AST.multiline?/1","doc":"iex> \"\"\"\n    ...> def foo(x)\n    ...>     when is_integer(x) do\n    ...>   {:foo, x}\n    ...> end\n    ...> \"\"\"\n    ...> |> Sourceror.parse_string!() |> multiline?()\n    true\n\n    iex> \"\"\"\n    ...> def foo(x) when is_integer(x) do\n    ...>   {:foo, x}\n    ...> end\n    ...> \"\"\"\n    ...> |> Sourceror.parse_string!() |> multiline?()\n    false\n\n    iex> \"\"\"\n    ...> {\n    ...>   x,\n    ...>   y\n    ...> }\n    ...> \"\"\"\n    ...> |> Sourceror.parse_string!() |> multiline?()\n    true\n\n    iex> \"\"\"\n    ...> {x, y}\n    ...> \"\"\"\n    ...> |> Sourceror.parse_string!() |> multiline?()\n    false","ref":"Recode.AST.html#multiline?/1-examples"},{"type":"function","title":"Recode.AST.name/1","doc":"Converts AST representing a name to a string.\n\nThis function suppresses the prefix `\"Elixir.\"`.","ref":"Recode.AST.html#name/1"},{"type":"function","title":"Examples - Recode.AST.name/1","doc":"iex> name([Recode, AST])\n    \"Recode.AST\"\n\n    iex> name(Recode.AST)\n    \"Recode.AST\"","ref":"Recode.AST.html#name/1-examples"},{"type":"function","title":"Recode.AST.put_newlines/2","doc":"Puts the given value `newlines` under the key `nevlines` in\n`meta[:end_of_expression]`.","ref":"Recode.AST.html#put_newlines/2"},{"type":"function","title":"Recode.AST.put_value/2","doc":"Puts the given `value` in the `:__block__` AST.","ref":"Recode.AST.html#put_value/2"},{"type":"function","title":"Examples - Recode.AST.put_value/2","doc":"iex> \"[1, 2]\"\n    ...> |> Sourceror.parse_string!()\n    ...> |> get_value()\n    ...> |> Enum.map(fn ast -> put_value(ast, \"0\") end)\n    ...> |> Enum.map(&get_value/1)\n    [\"0\", \"0\"]","ref":"Recode.AST.html#put_value/2-examples"},{"type":"function","title":"Recode.AST.to_same_line/1","doc":"","ref":"Recode.AST.html#to_same_line/1"},{"type":"function","title":"Recode.AST.update_call/2","doc":"Update a function call.\n\nThe keyword list `updates` can have the keys `name`, `meta` and `args`.","ref":"Recode.AST.html#update_call/2"},{"type":"function","title":"Examples - Recode.AST.update_call/2","doc":"iex> quote do\n    ...>   foo(x)\n    ...> end\n    ...> |> update_call(name: :bar)\n    ...> |> Macro.to_string()\n    \"bar(x)\"","ref":"Recode.AST.html#update_call/2-examples"},{"type":"function","title":"Recode.AST.update_capture/2","doc":"Updates the function name of a capture.","ref":"Recode.AST.html#update_capture/2"},{"type":"function","title":"Recode.AST.update_definition/2","doc":"Updates the AST representing a definition.\n\nThe keyword list `updates` can have the keys `name`, `meta` and `args`.","ref":"Recode.AST.html#update_definition/2"},{"type":"function","title":"Examples - Recode.AST.update_definition/2","doc":"iex> ast = Sourceror.parse_string!(\"def foo(x), do: x\")\n    iex> ast |> update_definition(name: :bar) |> Macro.to_string()\n    \"def bar(x), do: x\"\n    iex> ast |> update_definition(args: [{:y, [], nil}]) |> Macro.to_string()\n    \"def foo(y), do: x\"","ref":"Recode.AST.html#update_definition/2-examples"},{"type":"function","title":"Recode.AST.update_dot_call/2","doc":"Update a dotted function call.","ref":"Recode.AST.html#update_dot_call/2"},{"type":"function","title":"Examples - Recode.AST.update_dot_call/2","doc":"iex> ast = quote do\n    ...>   Foo.foo(x)\n    ...> end\n    iex> update_dot_call(ast, name: :bar)\n    {{:., [], [{:__aliases__, [alias: false], [:Foo]}, :bar]}, [], [{:x, [], Recode.ASTTest}]}","ref":"Recode.AST.html#update_dot_call/2-examples"},{"type":"function","title":"Recode.AST.update_spec/2","doc":"Updates a spec.\n\nThe keyword list `updates` can have the keys `name`, `meta`, `args` and\n`return`.","ref":"Recode.AST.html#update_spec/2"},{"type":"function","title":"Examples - Recode.AST.update_spec/2","doc":"iex> quote do\n    ...>   @spec foo(integer()) :: integer()\n    ...> end\n    ...> |> update_spec(name: :bar, return: {:term, [], []})\n    ...> |> Macro.to_string()\n    \"@spec bar(integer()) :: term()\"","ref":"Recode.AST.html#update_spec/2-examples"},{"type":"module","title":"Recode.Config","doc":"This module reads the `Recode` configuration.","ref":"Recode.Config.html"},{"type":"function","title":"Recode.Config.read/1","doc":"","ref":"Recode.Config.html#read/1"},{"type":"function","title":"Recode.Config.validate/1","doc":"","ref":"Recode.Config.html#validate/1"},{"type":"function","title":"Recode.Config.validate/2","doc":"","ref":"Recode.Config.html#validate/2"},{"type":"type","title":"Recode.Config.config/0","doc":"","ref":"Recode.Config.html#t:config/0"},{"type":"module","title":"Recode.Context","doc":"This module provides functions to traverse an AST with a `%Context{}`.","ref":"Recode.Context.html"},{"type":"module","title":"Examples - Recode.Context","doc":"The following example shows the `%Context{}` for the definition of\n`MyApp.Bar.bar/1`.\n\n    iex> alias Rewrite.Source\n    ...> alias Recode.Context\n    ...> \"\"\"\n    ...> defmodule MyApp.Foo do\n    ...>   def foo, do: :foo\n    ...> end\n    ...>\n    ...> defmodule MyApp.Bar do\n    ...>   alias MyApp.Foo\n    ...>\n    ...>   def bar(x) do\n    ...>     {Foo.foo(), x}\n    ...>   end\n    ...> end\n    ...> \"\"\"\n    ...> |> Source.Ex.from_string()\n    ...> |> Source.get(:quoted)\n    ...> |> Zipper.zip()\n    ...> |> Context.traverse(nil, fn\n    ...>   zipper, context, nil ->\n    ...>     case context.definition do\n    ...>       {{:def, :bar, 1}, _meta} -> {zipper, context, context}\n    ...>       _def -> {zipper, context, nil}\n    ...>     end\n    ...>   zipper, context, acc ->\n    ...>     {zipper, context, acc}\n    ...> end)\n    ...> |> elem(1) |> Map.put(:node, nil)\n    %Context{\n      node: nil,\n      aliases: [\n        {MyApp.Foo,\n         [\n           trailing_comments: [],\n           leading_comments: [],\n           end_of_expression: [newlines: 2, line: 6, column: 18],\n           line: 6,\n           column: 3\n         ], nil}\n      ],\n      assigns: %{},\n      definition:\n        {{:def, :bar, 1},\n         [\n           trailing_comments: [],\n           leading_comments: [],\n           do: [line: 8, column: 14],\n           end: [line: 10, column: 3],\n           line: 8,\n           column: 3\n         ]},\n      imports: [],\n      module:\n        {MyApp.Bar,\n         [\n           trailing_comments: [],\n           leading_comments: [],\n           do: [line: 5, column: 21],\n           end: [line: 11, column: 1],\n           line: 5,\n           column: 1\n         ]},\n      requirements: [],\n      usages: []\n    }","ref":"Recode.Context.html#module-examples"},{"type":"function","title":"Recode.Context.assign/3","doc":"Assigns the given `value` under `key` to the `context`.","ref":"Recode.Context.html#assign/3"},{"type":"function","title":"Recode.Context.assigns/2","doc":"Merges the given `map` to the assigns of the `context`.","ref":"Recode.Context.html#assigns/2"},{"type":"function","title":"Recode.Context.definition?/2","doc":"Returns true if `definition` satisfies the assumption.","ref":"Recode.Context.html#definition?/2"},{"type":"function","title":"Recode.Context.doc?/1","doc":"Returns `true` if `@doc` is available and not set to `@doc false`.","ref":"Recode.Context.html#doc?/1"},{"type":"function","title":"Recode.Context.doc?/2","doc":"Returns `true` if `@doc false`.","ref":"Recode.Context.html#doc?/2"},{"type":"function","title":"Recode.Context.expand_mfa/2","doc":"Expands the module alias for the given `mfa`.","ref":"Recode.Context.html#expand_mfa/2"},{"type":"function","title":"Recode.Context.impl?/1","doc":"Returns `true` if an `impl` is available.","ref":"Recode.Context.html#impl?/1"},{"type":"function","title":"Recode.Context.module/1","doc":"Returns the current module of a context.","ref":"Recode.Context.html#module/1"},{"type":"function","title":"Recode.Context.moduledoc?/1","doc":"Returns `true` if `@moduledoc` is available and not set to `@moduledoc false`.","ref":"Recode.Context.html#moduledoc?/1"},{"type":"function","title":"Recode.Context.moduledoc?/2","doc":"Returns `true` if `@moduledoc false`.","ref":"Recode.Context.html#moduledoc?/2"},{"type":"function","title":"Recode.Context.spec?/1","doc":"Returns `true` if a `spec` is available.","ref":"Recode.Context.html#spec?/1"},{"type":"function","title":"Recode.Context.traverse/2","doc":"Traverses the given `zipper` and applies `fun` on each node.\n\nThe `fun` gets the current `zipper` and `context` as arguments.","ref":"Recode.Context.html#traverse/2"},{"type":"function","title":"Recode.Context.traverse/3","doc":"Traverses the given `zipper` with an `acc` and applies `fun` on each node.","ref":"Recode.Context.html#traverse/3"},{"type":"type","title":"Recode.Context.t/0","doc":"","ref":"Recode.Context.html#t:t/0"},{"type":"type","title":"Recode.Context.zipper/0","doc":"","ref":"Recode.Context.html#t:zipper/0"},{"type":"behaviour","title":"Recode.Formatter","doc":"The default formatter and the formatter bebaviour.","ref":"Recode.Formatter.html"},{"type":"function","title":"Recode.Formatter.format/3","doc":"","ref":"Recode.Formatter.html#format/3"},{"type":"callback","title":"Recode.Formatter.format/3","doc":"","ref":"Recode.Formatter.html#c:format/3"},{"type":"function","title":"Recode.Formatter.format/4","doc":"","ref":"Recode.Formatter.html#format/4"},{"type":"callback","title":"Recode.Formatter.format/4","doc":"","ref":"Recode.Formatter.html#c:format/4"},{"type":"module","title":"Recode.FormatterPlugin","doc":"Defines Recode formatter plugin for `mix format`.\n\nSince Elixir 1.13, it is possible to define custom formatter plugins. This\nplugin allows you to run Recode autocorrecting tasks together when executing\n`mix format`.\n\nTo use this formatter, simply add `Recode.FormatterPlugin` to your\n`.formatter.exs` plugins:\n\n```\n  [\n    inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"],\n    plugins: [Recode.FormatterPlugin]\n  ]\n```\n\nBy default it uses the `.recode.exs` configuration file.\n\nIf your project does not have a `.recode.exs` configuration file or if you\nwant to overwrite the configuration, you can pass the configuration using the\n`recode` option:\n\n```\n  [\n    inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"],\n    plugins: [Recode.FormatterPlugin],\n    recode: [\n      tasks: [\n        {Recode.Task.AliasExpansion, []},\n        {Recode.Task.EnforceLineLength, []},\n        {Recode.Task.SinglePipe, []}\n      ]\n    ]\n  ]\n```","ref":"Recode.FormatterPlugin.html"},{"type":"module","title":"Recode.IO","doc":"This module provides IO functions and contains the color schema for `Recode`.","ref":"Recode.IO.html"},{"type":"function","title":"Recode.IO.puts/1","doc":"Similar `to write/1`, but adds a newline at the end.","ref":"Recode.IO.html#puts/1"},{"type":"function","title":"Recode.IO.reverse/0","doc":"","ref":"Recode.IO.html#reverse/0"},{"type":"function","title":"Recode.IO.reverse_off/0","doc":"","ref":"Recode.IO.html#reverse_off/0"},{"type":"function","title":"Recode.IO.write/1","doc":"Formats a chardata-like argument by converting named ANSI sequences into\nactual ANSI codes and writes it to `:stdio`.","ref":"Recode.IO.html#write/1"},{"type":"type","title":"Recode.IO.chardata/0","doc":"","ref":"Recode.IO.html#t:chardata/0"},{"type":"type","title":"Recode.IO.color/0","doc":"","ref":"Recode.IO.html#t:color/0"},{"type":"module","title":"Recode.Issue","doc":"An `Issue` struct to track findings by the chechers.","ref":"Recode.Issue.html"},{"type":"function","title":"Recode.Issue.new/4","doc":"Creates a new `%Issue{}`","ref":"Recode.Issue.html#new/4"},{"type":"function","title":"Examples - Recode.Issue.new/4","doc":"iex> Recode.Issue.new(Test, \"kaput\", line: 1, column: 1)\n    %Recode.Issue{reporter: Test, message: \"kaput\", line: 1, column: 1, meta: nil}\n\n    iex> Recode.Issue.new(Test, foo: \"bar\")\n    %Recode.Issue{reporter: Test, message: nil, line: nil, column: nil, meta: [foo: \"bar\"]}","ref":"Recode.Issue.html#new/4-examples"},{"type":"type","title":"Recode.Issue.t/0","doc":"","ref":"Recode.Issue.html#t:t/0"},{"type":"behaviour","title":"Recode.Task","doc":"The behaviour for a `recode` task.","ref":"Recode.Task.html"},{"type":"callback","title":"Recode.Task.config/1","doc":"Returns the configuration for the given `key`.","ref":"Recode.Task.html#c:config/1"},{"type":"callback","title":"Recode.Task.run/2","doc":"Applies a task with the given `source` and `opts`.","ref":"Recode.Task.html#c:run/2"},{"type":"module","title":"Recode.Utils","doc":"This module provides utility functions for `recode`.","ref":"Recode.Utils.html"},{"type":"function","title":"Recode.Utils.ends_with?/2","doc":"Returns `true` id `value` ends with `suffix`.\n\nBoth, value and suffix must be lists or module aliases.","ref":"Recode.Utils.html#ends_with?/2"},{"type":"function","title":"Examples - Recode.Utils.ends_with?/2","doc":"iex> Recode.Utils.ends_with?(Foo.Bar, Bar)\n    true\n    iex> Recode.Utils.ends_with?(Foo, Foo.Bar)\n    false\n    iex> Recode.Utils.ends_with?(Foo.Bar, Baz)\n    false\n\n    iex> Recode.Utils.ends_with?([1, 2, 3], [2, 3])\n    true\n    iex> Recode.Utils.ends_with?([1, 2, 3], [2, 9])\n    false","ref":"Recode.Utils.html#ends_with?/2-examples"},{"type":"module","title":"Recode.Task.AliasExpansion","doc":"Multi aliases makes module uses harder to search for in large code bases.\n\n        # preferred\n        alias Module.Foo\n        alias Module.Bar\n\n        # not preferred\n        alias Module.{Foo, Bar}\n\nThis task rewrites the code when `mix recode` runs with `autocorrect: true`.","ref":"Recode.Task.AliasExpansion.html"},{"type":"module","title":"Recode.Task.AliasOrder","doc":"Alphabetically sorted lists are easier to read.\n\n    # preferred\n\n    alias Alpha\n    alias Bravo\n    alias Delta.{Echo, Foxtrot}\n\n    # not preferred\n\n    alias Delta.{Foxtrot, Echo}\n    alias Alpha\n    alias Bravo","ref":"Recode.Task.AliasOrder.html"},{"type":"module","title":"Recode.Task.EnforceLineLength","doc":"The `EnforceLineLength` task writes multiline expressions into one line if\nthey do not exceed the maximum line length.","ref":"Recode.Task.EnforceLineLength.html"},{"type":"module","title":"Options - Recode.Task.EnforceLineLength","doc":"* `:skip` - specifies expressions to skip.\n  * `:ignore` - specifies expressions to ignore.","ref":"Recode.Task.EnforceLineLength.html#module-options"},{"type":"module","title":"Examples - Recode.Task.EnforceLineLength","doc":"The following code is not changed by the Elixir Formatter.\n```Elixir\nfn\n  x ->\n    {\n      :ok,\n      x\n    }\nend\n```\nThe `EnforceLineLength` task rewrite this to\n```Elixir\nfn x -> {:ok, x} end\n```\nand with the option `[ignore: :fn]` to\n```Elixir\nfn\n  x -> {:ok, x}\nend\n```\nand with the option `skip: :fn` the code keeps unchanged.","ref":"Recode.Task.EnforceLineLength.html#module-examples"},{"type":"module","title":"Recode.Task.Format","doc":"This task runs the Elixir formatter.\n\nThis task runs as first task by any `mix recode` call.","ref":"Recode.Task.Format.html"},{"type":"module","title":"Recode.Task.PipeFunOne","doc":"Add parentheses to one-arity functions.\n\n    # preferred\n    some_string |> String.downcase() |> String.trim()\n\n    # not preferred\n    some_string |> String.downcase |> String.trim\n\nThis task rewrites the code when `mix recode` runs with `autocorrect: true`.","ref":"Recode.Task.PipeFunOne.html"},{"type":"module","title":"Recode.Task.SinglePipe","doc":"Pipes (`|>`) should only be used when piping data through multiple calls.\n\n    # preferred\n    some_string |> String.downcase() |> String.trim()\n    Enum.reverse(some_enum)\n\n    # not preferred\n    some_enum |> Enum.reverse()\n\n`SinglePipe` does not change a single `|>` that starts with a none zero arity\nfunction.\n\n    # will not be changed\n    one(:a) |> two()\n\nThis task rewrites the code when `mix recode` runs with `autocorrect: true`.","ref":"Recode.Task.SinglePipe.html"},{"type":"module","title":"Recode.Task.Specs","doc":"Function should have specs.","ref":"Recode.Task.Specs.html"},{"type":"module","title":"Options - Recode.Task.Specs","doc":"* `:only` - `:public`, `:visible`\n  * `:macros` - when `true`, macros are also checked, defaults to `false`.","ref":"Recode.Task.Specs.html#module-options"},{"type":"module","title":"Recode.Task.TestFileExt","doc":"Tests must be in a file with the extension `*_test.exs`.\n\nThis module searches for `*_test.ex` to rename the file and/or report an\nissue.","ref":"Recode.Task.TestFileExt.html"},{"type":"module","title":"Recode.Task.UnusedVariable","doc":"Prepend unused variables with `_`","ref":"Recode.Task.UnusedVariable.html"}],"content_type":"text/markdown"}